import * as i0 from '@angular/core';
import { computed, signal, input, output, inject, ElementRef, Renderer2, effect, untracked, Directive, Component } from '@angular/core';
import { getDragEventByElement, checkMouseOverInContainer } from '@libs-ui/utils';
import { Subscription, Subject, fromEvent, tap, takeUntil, switchMap, interval } from 'rxjs';
import { CommonModule } from '@angular/common';

/* eslint-disable @typescript-eslint/no-explicit-any */
class LibsUiComponentsScrollOverlayDirective {
    // #region PROPERTY
    styles = computed(() => `
      .scrollbar-track{
         background-color:${this.scrollbarColor()};
      }
      .scrollbar-track:hover{
        background-color:${this.scrollbarHoverColor()};
      }
      .scrollbar-track-X {
        width:100%;
        position: absolute;
        bottom: 0;
        left: 0;
        visibility: hidden;
        cursor: pointer;
        opacity: 0;
        z-index: 1;
        transition: opacity 0.3s ease, visibility 0.3s ease;
      }

      .scrollbar-track-Y {
        height:100%;
        position: absolute;
        top: 0;
        right: 0;
        visibility: hidden;
        cursor: pointer;
        opacity: 0;
        z-index: 1;
        transition: opacity 0.3s ease, visibility 0.3s ease;
      }

      .scrollbar-thumb{
        background-color:${this.scrollThumbColor()};
      }
      .scrollbar-thumb:hover{
        background-color:${this.scrollThumbHoverColor()};
      }

      .scrollbar-thumb-X {
        height: calc(100% - ${this.scrollbarPadding() * 2}px);
        bottom: ${this.scrollbarPadding()}px;
        border-radius: 4px;
        cursor: move;
        transition: background-color 0.3s;
        position: absolute;
      }

      .scrollbar-thumb-Y {
        width: calc(100% - ${this.scrollbarPadding() * 2}px);
        right: ${this.scrollbarPadding()}px;
        border-radius: 4px;
        cursor: move;
        transition: background-color 0.3s;
        position: absolute;
      }
  `, {});
    isScrollThumb = signal(false);
    keepDisplayThumb = signal(false);
    subsX = new Subscription();
    subsY = new Subscription();
    scrollbarWidth = computed(() => this.options()?.scrollbarWidth ?? 10); // Chiều rộng thanh cuộn
    scrollbarPadding = computed(() => this.options()?.scrollbarPadding ?? 2); // Chiều rộng thanh cuộn
    scrollbarColor = computed(() => this.options()?.scrollbarColor ?? '');
    scrollbarHoverColor = computed(() => this.options()?.scrollbarColor ?? '#CDD0D640');
    scrollThumbColor = computed(() => this.options()?.scrollThumbColor ?? '#CDD0D6');
    scrollThumbHoverColor = computed(() => this.options()?.scrollThumbHoverColor ?? '#9CA2AD');
    divContainer = document.createElement('div');
    trackX = document.createElement('div');
    thumbX = document.createElement('div');
    trackY = document.createElement('div');
    thumbY = document.createElement('div');
    onDestroy = new Subject();
    // #region INPUT
    debugMode = input(false);
    ignoreInit = input(false);
    classContainer = input('', { transform: value => value ?? '' });
    options = input(Object.assign({}));
    elementCheckScrollX = input();
    elementCheckScrollY = input();
    elementScroll = input();
    // #region OUTPUT
    outScroll = output();
    outScrollX = output();
    outScrollY = output();
    outScrollTop = output();
    outScrollBottom = output();
    // #region INJECT
    element = inject(ElementRef);
    render2 = inject(Renderer2);
    constructor() {
        effect(() => {
            if (this.ignoreInit()) {
                return;
            }
            const options = this.options();
            this.divContainer.className = '';
            this.classContainer()?.split(' ').forEach(className => {
                if (!className) {
                    return;
                }
                this.divContainer.classList.add(className);
            });
            untracked(() => {
                this.Element.classList.toggle('overflow-hidden', options?.scrollX === 'hidden' && options?.scrollY === 'hidden');
                if (options?.scrollX !== 'hidden') {
                    this.subsX.unsubscribe();
                    this.trackX.className = '';
                    this.thumbX.className = '';
                    this.trackX.style.height = `${this.scrollbarWidth()}px`;
                    this.createScrollbar('X', this.trackX, this.thumbX);
                    this.bindEventsScrollBar('X', this.trackX);
                    this.handlerDragAndDropThumb('X');
                    this.handlerClickTrack('X');
                }
                if (options?.scrollY !== 'hidden') {
                    this.trackY.className = '';
                    this.thumbY.className = '';
                    this.trackY.style.width = `${this.scrollbarWidth()}px`;
                    this.subsY.unsubscribe();
                    this.createScrollbar('Y', this.trackY, this.thumbY);
                    this.bindEventsScrollBar('Y', this.trackY);
                    this.handlerDragAndDropThumb('Y');
                    this.handlerClickTrack('Y');
                }
            });
        });
    }
    // #region FUNCTIONS
    get Element() {
        return this.elementScroll() || this.element.nativeElement;
    }
    createScrollbar(scrollDirection, trackEl, thumbEl) {
        const idStyleTag = "#id-style-tag-custom-scroll-overlay";
        const styleElCustomScrollOverlay = document.getElementById(idStyleTag);
        if (!styleElCustomScrollOverlay) {
            const styleEl = document.createElement('style');
            styleEl.setAttribute('id', idStyleTag);
            styleEl.innerHTML = this.styles();
            document.head.append(styleEl);
        }
        const stylesProperty = {
            "box-sizing": "border-box",
            "scrollbar-width": "none",
            "scrollbar-color": "transparent transparent",
            "overflow": "hidden",
            "overflow-x": `${this.options()?.scrollX || 'scroll'}`,
            "overflow-y": `${this.options()?.scrollY || 'scroll'}`
        };
        Object.keys(stylesProperty).forEach(key => {
            this.render2.setStyle(this.Element, key, stylesProperty[key], 1);
        });
        trackEl.classList.add(`scrollbar-track`);
        trackEl.classList.add(`scrollbar-track-${scrollDirection}`);
        thumbEl.classList.add(`scrollbar-thumb`);
        thumbEl.classList.add(`scrollbar-thumb-${scrollDirection}`);
        trackEl.appendChild(thumbEl);
        if (this.Element.className) {
            this.Element.className.split(' ').forEach((className) => {
                if (className && (['w-full', 'w-screen', 'h-full', 'h-screen', 'shrink-0'].includes(className) || className.includes('min-h-') || className.includes('min-w-') || /^(!?)(h|w)-\[[0-9]+px\]$/.test(className)) && !this.divContainer.classList.contains(className)) {
                    this.divContainer.classList.add(className);
                }
            });
            if (!this.Element.className.includes('min-h-')) {
                this.divContainer.classList.add('min-h-0');
            }
            if (!this.Element.className.includes('min-w-')) {
                this.divContainer.classList.add('min-w-0');
            }
        }
        this.divContainer.appendChild(trackEl);
        if (!this.divContainer.style.position) {
            this.Element.parentElement?.insertBefore(this.divContainer, this.Element);
            this.divContainer.style.position = 'relative';
        }
        this.divContainer.append(this.Element);
        this.updateScrollbarSize(scrollDirection);
    }
    bindEventsScrollBar(scrollDirection, trackEl) {
        let scrollLeft = this.Element.scrollLeft;
        let scrollTop = this.Element.scrollTop;
        const subs = fromEvent(this.Element, 'scroll').pipe(tap((event) => {
            const target = this.Element;
            this.outScroll.emit(event);
            if (scrollDirection === 'X') {
                if (target.scrollLeft && (target.scrollLeft + target.offsetWidth >= target.scrollWidth)) {
                    target.scrollLeft = target.scrollWidth - target.offsetWidth - (target.offsetWidth - target.clientWidth);
                }
                if (target.scrollLeft !== scrollLeft) {
                    this.outScrollX.emit(event);
                }
                scrollLeft = target.scrollLeft;
                this.updateScrollbarPosition(scrollDirection);
                return;
            }
            if (target.scrollTop === scrollTop) {
                return;
            }
            this.updateScrollbarPosition(scrollDirection);
            scrollTop = target.scrollTop;
            this.outScrollY.emit(event);
            if (target.scrollTop === 0) {
                return this.outScrollTop.emit(event);
            }
            if (target.scrollHeight <= target.scrollTop + target.offsetHeight + 3) {
                return this.outScrollBottom.emit(event);
            }
        }), takeUntil(this.onDestroy)).subscribe();
        subs.add(fromEvent(document, 'resize').pipe(tap(this.updateScrollbarSize.bind(this, scrollDirection)), takeUntil(this.onDestroy)).subscribe());
        const mouseLeave = fromEvent(this.divContainer, 'mouseleave');
        const mouseenter = fromEvent(this.divContainer, 'mouseenter');
        subs.add(mouseenter.pipe(tap(() => {
            if (scrollDirection === 'X' && !this.options()?.scrollXOpacity0 || scrollDirection === 'Y' && !this.options()?.scrollYOpacity0) {
                trackEl.style.visibility = 'visible';
                trackEl.style.opacity = '1';
            }
            this.updateScrollbarSize(scrollDirection);
        }), switchMap(() => interval(1000).pipe(takeUntil(mouseLeave))), tap(this.updateScrollbarSize.bind(this, scrollDirection)), takeUntil(this.onDestroy)).subscribe());
        subs.add(mouseLeave.pipe(tap(() => {
            if (this.keepDisplayThumb()) {
                return;
            }
            trackEl.style.visibility = 'hidden';
            trackEl.style.opacity = '0';
        }), takeUntil(this.onDestroy)).subscribe());
        if (scrollDirection === 'X') {
            this.subsX = subs;
            return;
        }
        if (scrollDirection === 'Y') {
            this.subsY = subs;
            return;
        }
    }
    handlerClickTrack(scrollDirection) {
        const elementTrack = scrollDirection === 'X' ? this.trackX : this.trackY;
        const elementThumb = scrollDirection === 'X' ? this.thumbX : this.thumbY;
        const subs = scrollDirection === 'X' ? this.subsX : this.subsY;
        subs.add(fromEvent(elementTrack, 'click').subscribe(e => {
            if (this.isScrollThumb()) {
                return;
            }
            if ((scrollDirection === 'X' && e.clientX < elementThumb.getBoundingClientRect().left) || (scrollDirection === 'Y' && e.clientY < elementThumb.getBoundingClientRect().top)) {
                this.updateScrollPositionByUserAction(scrollDirection, e, 'smooth', 0);
                return;
            }
            if (scrollDirection === 'X') {
                this.updateScrollPositionByUserAction(scrollDirection, e, 'smooth', -1 * elementThumb.getBoundingClientRect().width);
                return;
            }
            this.updateScrollPositionByUserAction(scrollDirection, e, 'smooth', -1 * elementThumb.getBoundingClientRect().height);
        }));
    }
    handlerDragAndDropThumb(scrollDirection) {
        const elementTrack = scrollDirection === 'X' ? this.trackX : this.trackY;
        const elementThumb = scrollDirection === 'X' ? this.thumbX : this.thumbY;
        const subs = scrollDirection === 'X' ? this.subsX : this.subsY;
        let lengthThumbToPointClick = 0;
        subs.add(getDragEventByElement({
            elementMouseDown: elementThumb,
            functionMouseDown: (mouseEvent) => {
                this.isScrollThumb.set(true);
                this.keepDisplayThumb.set(true);
                if (scrollDirection === 'X') {
                    lengthThumbToPointClick = elementThumb.getBoundingClientRect().left - mouseEvent.clientX;
                    return;
                }
                lengthThumbToPointClick = elementThumb.getBoundingClientRect().top - mouseEvent.clientY;
            },
            functionMouseUp: (mouseEvent) => {
                this.keepDisplayThumb.set(false);
                lengthThumbToPointClick = 0;
                if (!checkMouseOverInContainer(mouseEvent, this.Element)) {
                    elementTrack.style.visibility = 'hidden';
                    elementTrack.style.opacity = '0';
                }
                setTimeout(() => {
                    this.isScrollThumb.set(false);
                }, 250);
            },
            onDestroy: this.onDestroy
        }).subscribe((mouseEvent) => {
            this.updateScrollPositionByUserAction(scrollDirection, mouseEvent, 'auto', lengthThumbToPointClick);
        }));
    }
    updateScrollPositionByUserAction(scrollDirection, e, behavior, lengthThumbToPointClick = 0) {
        e.stopPropagation();
        if (scrollDirection === 'X') {
            const containerWidth = this.Element.offsetWidth;
            const contentWidth = (this.elementCheckScrollX() || this.Element).scrollWidth;
            const thumbPosition = e.clientX - this.Element.getBoundingClientRect().left + lengthThumbToPointClick;
            const scrollLeft = (thumbPosition / (containerWidth - this.thumbX.offsetWidth)) * (contentWidth - containerWidth);
            this.Element.scroll({ left: scrollLeft, behavior });
            return;
        }
        const containerHeight = this.Element.offsetHeight;
        const contentHeight = (this.elementCheckScrollY() || this.Element).scrollHeight;
        const thumbPosition = e.clientY - this.Element.getBoundingClientRect().top + lengthThumbToPointClick;
        const scrollTop = (thumbPosition / (containerHeight - this.thumbY.offsetHeight)) * (contentHeight - containerHeight);
        this.Element.scroll({ top: scrollTop, behavior });
    }
    updateScrollbarSize(scrollDirection) {
        if (scrollDirection === 'X') {
            const containerWidth = this.Element.offsetWidth;
            const contentWidth = (this.elementCheckScrollX() || this.Element).scrollWidth;
            const thumbWidth = (containerWidth / contentWidth) * (containerWidth);
            this.thumbX.style.width = `${thumbWidth}px`;
            this.trackX.style.display = 'none';
            if (contentWidth > containerWidth) {
                this.trackX.style.display = 'block';
            }
            this.updateScrollbarPosition(scrollDirection);
            return;
        }
        const containerHeight = this.Element.offsetHeight;
        const contentHeight = (this.elementCheckScrollY() || this.Element).scrollHeight;
        const thumbHeight = (containerHeight / contentHeight) * (containerHeight);
        this.thumbY.style.height = `${Math.max(20, thumbHeight)}px`;
        this.trackY.style.display = 'none';
        if (contentHeight > containerHeight) {
            this.trackY.style.display = 'block';
        }
        this.updateScrollbarPosition('Y');
    }
    updateScrollbarPosition(scrollDirection) {
        if (scrollDirection === 'X') {
            const containerWidth = this.Element.offsetWidth;
            const contentWidth = (this.elementCheckScrollX() || this.Element).scrollWidth;
            const scrollLeft = this.Element.scrollLeft;
            const thumbPosition = (scrollLeft / (contentWidth - containerWidth)) * (containerWidth - this.thumbX.offsetWidth);
            this.thumbX.style.left = `${thumbPosition}px`;
            return;
        }
        const containerHeight = this.Element.offsetHeight;
        const contentHeight = (this.elementCheckScrollY() || this.Element).scrollHeight;
        const scrollTop = this.Element.scrollTop;
        const thumbPosition = (scrollTop / (contentHeight - containerHeight)) * (containerHeight - this.thumbY.offsetHeight);
        this.thumbY.style.top = `${thumbPosition}px`;
    }
    ngOnDestroy() {
        this.divContainer.remove();
        this.subsX.unsubscribe();
        this.subsY.unsubscribe();
        this.onDestroy.next();
        this.onDestroy.complete();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsScrollOverlayDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "18.2.13", type: LibsUiComponentsScrollOverlayDirective, isStandalone: true, selector: "[LibsUiComponentsScrollOverlayDirective]", inputs: { debugMode: { classPropertyName: "debugMode", publicName: "debugMode", isSignal: true, isRequired: false, transformFunction: null }, ignoreInit: { classPropertyName: "ignoreInit", publicName: "ignoreInit", isSignal: true, isRequired: false, transformFunction: null }, classContainer: { classPropertyName: "classContainer", publicName: "classContainer", isSignal: true, isRequired: false, transformFunction: null }, options: { classPropertyName: "options", publicName: "options", isSignal: true, isRequired: false, transformFunction: null }, elementCheckScrollX: { classPropertyName: "elementCheckScrollX", publicName: "elementCheckScrollX", isSignal: true, isRequired: false, transformFunction: null }, elementCheckScrollY: { classPropertyName: "elementCheckScrollY", publicName: "elementCheckScrollY", isSignal: true, isRequired: false, transformFunction: null }, elementScroll: { classPropertyName: "elementScroll", publicName: "elementScroll", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { outScroll: "outScroll", outScrollX: "outScrollX", outScrollY: "outScrollY", outScrollTop: "outScrollTop", outScrollBottom: "outScrollBottom" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsScrollOverlayDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[LibsUiComponentsScrollOverlayDirective]',
                    standalone: true
                }]
        }], ctorParameters: () => [] });

;

class LibsUiComponentsScrollOverlayDemoComponent {
    // Demo content
    longContent = signal(`Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.`);
    longHorizontalContent = signal(`This is a very long horizontal content that will require scrolling to see all of it. It contains multiple sentences and words that extend beyond the container width. This demonstrates the horizontal scrolling capability of the scroll-overlay directive.`);
    // Demo options
    customStyleOptions = signal({
        scrollbarWidth: 12,
        scrollbarColor: '#f3f4f6',
        scrollbarHoverColor: '#e5e7eb',
        scrollThumbColor: '#3b82f6',
        scrollThumbHoverColor: '#2563eb',
        scrollbarPadding: 4
    });
    autoHideOptions = signal({
        scrollYOpacity0: true,
        scrollbarWidth: 8,
        scrollbarColor: 'transparent',
        scrollThumbColor: '#9ca3af',
        scrollThumbHoverColor: '#6b7280'
    });
    horizontalOptions = signal({
        scrollX: 'scroll',
        scrollY: 'hidden',
        scrollbarWidth: 8,
        scrollbarColor: '#f3f4f6',
        scrollThumbColor: '#3b82f6'
    });
    // Event handling
    lastEvent = signal('No events yet');
    onScroll(event) {
        this.lastEvent.set('Scroll event fired');
    }
    onScrollTop(event) {
        this.lastEvent.set('Reached top');
    }
    onScrollBottom(event) {
        this.lastEvent.set('Reached bottom');
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsScrollOverlayDemoComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: LibsUiComponentsScrollOverlayDemoComponent, isStandalone: true, selector: "lib-scroll-overlay-demo", ngImport: i0, template: "<div class=\"demo-container\">\n  <h2>Scroll Overlay Demo</h2>\n\n  <div class=\"demo-intro\">\n    <h3>Gi\u1EDBi thi\u1EC7u</h3>\n    <p>Demo n\u00E0y minh h\u1ECDa c\u00E1c t\u00EDnh n\u0103ng v\u00E0 c\u00E1ch s\u1EED d\u1EE5ng c\u1EE7a directive `scroll-overlay`. Demo bao g\u1ED3m 5 v\u00ED d\u1EE5 ch\u00EDnh:</p>\n    <ul>\n      <li><strong>Basic Usage</strong>: S\u1EED d\u1EE5ng c\u01A1 b\u1EA3n v\u1EDBi c\u1EA5u h\u00ECnh m\u1EB7c \u0111\u1ECBnh</li>\n      <li><strong>Custom Styling</strong>: Tu\u1EF3 ch\u1EC9nh m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc v\u00E0 padding c\u1EE7a thanh cu\u1ED9n</li>\n      <li><strong>Auto Hide</strong>: \u1EA8n/hi\u1EC7n thanh cu\u1ED9n khi hover</li>\n      <li><strong>Horizontal Scroll</strong>: Cu\u1ED9n ngang v\u1EDBi n\u1ED9i dung d\u00E0i</li>\n      <li><strong>Event Handling</strong>: X\u1EED l\u00FD c\u00E1c s\u1EF1 ki\u1EC7n scroll</li>\n    </ul>\n  </div>\n\n  <div class=\"demo-features\">\n    <h3>T\u00EDnh n\u0103ng Demo</h3>\n    <div class=\"features-grid\">\n      <div class=\"feature-item\">\n        <h4>Tu\u1EF3 bi\u1EBFn giao di\u1EC7n</h4>\n        <p>Thay \u0111\u1ED5i m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc, padding c\u1EE7a thanh cu\u1ED9n</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Hi\u1EC7u \u1EE9ng t\u01B0\u01A1ng t\u00E1c</h4>\n        <p>Hover effects, auto-hide khi kh\u00F4ng s\u1EED d\u1EE5ng</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>\u0110a h\u01B0\u1EDBng cu\u1ED9n</h4>\n        <p>H\u1ED7 tr\u1EE3 c\u1EA3 cu\u1ED9n d\u1ECDc v\u00E0 ngang</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Event handling</h4>\n        <p>Theo d\u00F5i c\u00E1c s\u1EF1 ki\u1EC7n scroll (top, bottom, scroll)</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Responsive</h4>\n        <p>Ho\u1EA1t \u0111\u1ED9ng t\u1ED1t tr\u00EAn m\u1ECDi k\u00EDch th\u01B0\u1EDBc m\u00E0n h\u00ECnh</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>T\u00EDch h\u1EE3p d\u1EC5 d\u00E0ng</h4>\n        <p>C\u00F3 th\u1EC3 th\u00EAm v\u00E0o b\u1EA5t k\u1EF3 container n\u00E0o</p>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"demo-api\">\n    <h3>API Reference</h3>\n\n    <div class=\"api-section\">\n      <h4>Inputs</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Input</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>options</td>\n              <td>IScrollOverlayOptions</td>\n              <td>Tu\u1EF3 ch\u1ECDn c\u1EA5u h\u00ECnh thanh cu\u1ED9n</td>\n            </tr>\n            <tr>\n              <td>debugMode</td>\n              <td>boolean</td>\n              <td>B\u1EADt ch\u1EBF \u0111\u1ED9 debug</td>\n            </tr>\n            <tr>\n              <td>ignoreInit</td>\n              <td>boolean</td>\n              <td>B\u1ECF qua kh\u1EDFi t\u1EA1o directive</td>\n            </tr>\n            <tr>\n              <td>classContainer</td>\n              <td>string</td>\n              <td>Th\u00EAm class cho container b\u1ECDc ngo\u00E0i</td>\n            </tr>\n            <tr>\n              <td>notShowScrollBarX</td>\n              <td>boolean</td>\n              <td>Kh\u00F4ng hi\u1EC3n th\u1ECB thanh cu\u1ED9n ngang</td>\n            </tr>\n            <tr>\n              <td>notShowScrollBarY</td>\n              <td>boolean</td>\n              <td>Kh\u00F4ng hi\u1EC3n th\u1ECB thanh cu\u1ED9n d\u1ECDc</td>\n            </tr>\n            <tr>\n              <td>elementCheckScrollX</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED d\u00F9ng \u0111\u1EC3 ki\u1EC3m tra scroll X</td>\n            </tr>\n            <tr>\n              <td>elementCheckScrollY</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED d\u00F9ng \u0111\u1EC3 ki\u1EC3m tra scroll Y</td>\n            </tr>\n            <tr>\n              <td>elementScroll</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED th\u1EF1c hi\u1EC7n scroll</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Outputs</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Output</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>outScroll</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll b\u1EA5t k\u1EF3</td>\n            </tr>\n            <tr>\n              <td>outScrollX</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll theo chi\u1EC1u ngang</td>\n            </tr>\n            <tr>\n              <td>outScrollY</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll theo chi\u1EC1u d\u1ECDc</td>\n            </tr>\n            <tr>\n              <td>outScrollTop</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll t\u1EDBi \u0111\u1EA7u (top)</td>\n            </tr>\n            <tr>\n              <td>outScrollBottom</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll t\u1EDBi cu\u1ED1i (bottom)</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Interface</h4>\n      <div class=\"interface-description\">\n        <p>Interface <code>IScrollOverlayOptions</code> \u0111\u1ECBnh ngh\u0129a c\u00E1c tu\u1EF3 ch\u1ECDn c\u1EA5u h\u00ECnh cho scroll-overlay directive:\n        </p>\n        <pre><code>export interface IScrollOverlayOptions {{ '{' }}\n  scrollbarWidth?: number;        // Chi\u1EC1u r\u1ED9ng thanh cu\u1ED9n (px)\n  scrollbarColor?: string;        // M\u00E0u n\u1EC1n track\n  scrollbarHoverColor?: string;   // M\u00E0u n\u1EC1n track khi hover\n  scrollThumbColor?: string;      // M\u00E0u thumb\n  scrollThumbHoverColor?: string; // M\u00E0u thumb khi hover\n  scrollbarPadding?: number;      // Padding c\u1EE7a scrollbar\n  scrollX?: 'hidden' | 'scroll';  // Ki\u1EC3u hi\u1EC3n th\u1ECB scroll X\n  scrollXOpacity0?: boolean;      // \u1EA8n track X khi kh\u00F4ng hover\n  scrollY?: 'hidden' | 'scroll';  // Ki\u1EC3u hi\u1EC3n th\u1ECB scroll Y\n  scrollYOpacity0?: boolean;      // \u1EA8n track Y khi kh\u00F4ng hover\n{{ '}' }}</code></pre>\n      </div>\n\n      <div class=\"interface-usage\">\n        <h5>V\u00ED d\u1EE5 s\u1EED d\u1EE5ng:</h5>\n        <pre><code>// C\u1EA5u h\u00ECnh c\u01A1 b\u1EA3n\nconst basicOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollbarWidth: 8,\n  scrollbarColor: '#f3f4f6',\n  scrollThumbColor: '#3b82f6'\n{{ '}' }};\n\n// C\u1EA5u h\u00ECnh n\u00E2ng cao v\u1EDBi hover effects\nconst advancedOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollbarWidth: 12,\n  scrollbarColor: '#f3f4f6',\n  scrollbarHoverColor: '#e5e7eb',\n  scrollThumbColor: '#3b82f6',\n  scrollThumbHoverColor: '#2563eb',\n  scrollbarPadding: 4,\n  scrollYOpacity0: true\n{{ '}' }};\n\n// C\u1EA5u h\u00ECnh cho scroll ngang\nconst horizontalOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollX: 'scroll',\n  scrollY: 'hidden',\n  scrollbarWidth: 8,\n  scrollbarColor: '#f3f4f6',\n  scrollThumbColor: '#3b82f6'\n{{ '}' }};</code></pre>\n      </div>\n\n      <div class=\"interface-notes\">\n        <h5>Ghi ch\u00FA:</h5>\n        <ul>\n          <li>T\u1EA5t c\u1EA3 c\u00E1c thu\u1ED9c t\u00EDnh \u0111\u1EC1u l\u00E0 optional (c\u00F3 d\u1EA5u ?)</li>\n          <li>N\u1EBFu kh\u00F4ng cung c\u1EA5p gi\u00E1 tr\u1ECB, directive s\u1EBD s\u1EED d\u1EE5ng gi\u00E1 tr\u1ECB m\u1EB7c \u0111\u1ECBnh</li>\n          <li>C\u00F3 th\u1EC3 k\u1EBFt h\u1EE3p nhi\u1EC1u options \u0111\u1EC3 t\u1EA1o ra giao di\u1EC7n thanh cu\u1ED9n ph\u00F9 h\u1EE3p</li>\n          <li>M\u00E0u s\u1EAFc c\u00F3 th\u1EC3 s\u1EED d\u1EE5ng b\u1EA5t k\u1EF3 \u0111\u1ECBnh d\u1EA1ng CSS color n\u00E0o (hex, rgb, rgba, etc.)</li>\n          <li>scrollX v\u00E0 scrollY ch\u1EC9 nh\u1EADn m\u1ED9t trong hai gi\u00E1 tr\u1ECB: 'hidden' ho\u1EB7c 'scroll'</li>\n        </ul>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Options (IScrollOverlayOptions)</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Thu\u1ED9c t\u00EDnh</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>scrollbarWidth</td>\n              <td>number</td>\n              <td>Chi\u1EC1u r\u1ED9ng thanh cu\u1ED9n (px)</td>\n            </tr>\n            <tr>\n              <td>scrollbarColor</td>\n              <td>string</td>\n              <td>M\u00E0u n\u1EC1n track</td>\n            </tr>\n            <tr>\n              <td>scrollbarHoverColor</td>\n              <td>string</td>\n              <td>M\u00E0u n\u1EC1n track khi hover</td>\n            </tr>\n            <tr>\n              <td>scrollThumbColor</td>\n              <td>string</td>\n              <td>M\u00E0u thumb</td>\n            </tr>\n            <tr>\n              <td>scrollThumbHoverColor</td>\n              <td>string</td>\n              <td>M\u00E0u thumb khi hover</td>\n            </tr>\n            <tr>\n              <td>scrollbarPadding</td>\n              <td>number</td>\n              <td>Padding c\u1EE7a scrollbar</td>\n            </tr>\n            <tr>\n              <td>scrollX</td>\n              <td>'hidden'|'scroll'</td>\n              <td>Ki\u1EC3u hi\u1EC3n th\u1ECB scroll X</td>\n            </tr>\n            <tr>\n              <td>scrollXOpacity0</td>\n              <td>boolean</td>\n              <td>\u1EA8n track X khi kh\u00F4ng hover</td>\n            </tr>\n            <tr>\n              <td>scrollY</td>\n              <td>'hidden'|'scroll'</td>\n              <td>Ki\u1EC3u hi\u1EC3n th\u1ECB scroll Y</td>\n            </tr>\n            <tr>\n              <td>scrollYOpacity0</td>\n              <td>boolean</td>\n              <td>\u1EA8n track Y khi kh\u00F4ng hover</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n  </div>\n\n  <!-- Basic Demo -->\n  <div class=\"demo-section\">\n    <h3>1. Basic Usage</h3>\n    <div class=\"demo-description\">\n      <p>S\u1EED d\u1EE5ng c\u01A1 b\u1EA3n v\u1EDBi c\u1EA5u h\u00ECnh m\u1EB7c \u0111\u1ECBnh c\u1EE7a scroll-overlay directive.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     style=\"width: 300px; height: 200px;\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Custom Styling Demo -->\n  <div class=\"demo-section\">\n    <h3>2. Custom Styling</h3>\n    <div class=\"demo-description\">\n      <p>Tu\u1EF3 ch\u1EC9nh m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc v\u00E0 padding c\u1EE7a thanh cu\u1ED9n.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollbarWidth: 12,\n       scrollbarColor: '#f3f4f6',\n       scrollThumbColor: '#3b82f6',\n       scrollbarPadding: 4\n     {{ '}' }}\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"customStyleOptions()\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Auto Hide Demo -->\n  <div class=\"demo-section\">\n    <h3>3. Auto Hide on Hover</h3>\n    <div class=\"demo-description\">\n      <p>\u1EA8n/hi\u1EC7n thanh cu\u1ED9n khi hover v\u00E0o container.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollYOpacity0: true,\n       scrollbarColor: 'transparent',\n       scrollThumbColor: '#9ca3af'\n     {{ '}' }}\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"autoHideOptions()\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Horizontal Scroll Demo -->\n  <div class=\"demo-section\">\n    <h3>4. Horizontal Scroll</h3>\n    <div class=\"demo-description\">\n      <p>Cu\u1ED9n ngang v\u1EDBi n\u1ED9i dung d\u00E0i.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollX: 'scroll',\n       scrollY: 'hidden'\n     {{ '}' }}\"&gt;\n  &lt;div style=\"white-space: nowrap;\"&gt;\n    N\u1ED9i dung ngang d\u00E0i...\n  &lt;/div&gt;\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"horizontalOptions()\"\n        style=\"width: 300px; height: 100px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px; white-space: nowrap;\">\n          {{ longHorizontalContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Event Handling Demo -->\n  <div class=\"demo-section\">\n    <h3>5. Event Handling</h3>\n    <div class=\"demo-description\">\n      <p>X\u1EED l\u00FD c\u00E1c s\u1EF1 ki\u1EC7n scroll.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     (outScroll)=\"onScroll($event)\"\n     (outScrollTop)=\"onScrollTop($event)\"\n     (outScrollBottom)=\"onScrollBottom($event)\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        (outScroll)=\"onScroll($event)\"\n        (outScrollTop)=\"onScrollTop($event)\"\n        (outScrollBottom)=\"onScrollBottom($event)\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n      <div class=\"event-log\">\n        <p>Last Event: {{ lastEvent() }}</p>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.demo-container{padding:24px;font-family:system-ui,-apple-system,sans-serif;max-width:1200px;margin:0 auto}.demo-intro{margin-bottom:32px}.demo-intro h3{color:#333;margin-bottom:16px}.demo-intro ul{list-style:none;padding:0}.demo-intro ul li{margin-bottom:8px;padding-left:20px;position:relative}.demo-intro ul li:before{content:\"\\2022\";position:absolute;left:0;color:#3b82f6}.demo-features{margin-bottom:32px}.demo-features h3{color:#333;margin-bottom:16px}.features-grid{display:grid;grid-template-columns:repeat(auto-fit,minmax(250px,1fr));gap:16px}.feature-item{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0}.feature-item h4{color:#1e40af;margin:0 0 8px}.feature-item p{margin:0;color:#64748b}.demo-api{margin-bottom:48px}.demo-api h3{color:#333;margin-bottom:24px}.api-section{margin-bottom:32px}.api-section h4{color:#1e40af;margin-bottom:16px}.api-table{overflow-x:auto}.api-table table{width:100%;border-collapse:collapse;background:#fff;border-radius:8px;border:1px solid #e2e8f0}.api-table table th,.api-table table td{padding:12px 16px;text-align:left;border-bottom:1px solid #e2e8f0}.api-table table th{background:#f8fafc;font-weight:600;color:#1e40af}.api-table table td{color:#64748b}.api-table table td:first-child{font-family:Fira Code,monospace;color:#334155}.api-table table td:nth-child(2){font-family:Fira Code,monospace;color:#3b82f6}.api-table table tr:last-child td{border-bottom:none}.demo-section{margin-bottom:48px}.demo-section h3{color:#333;margin-bottom:16px}.demo-description{margin-bottom:16px}.demo-description p{color:#64748b;margin-bottom:12px}.demo-description pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.demo-description pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155}.demo-box{display:flex;gap:16px;align-items:flex-start}.event-log{padding:16px;background:#f5f5f5;border-radius:4px;min-width:200px}.event-log p{margin:0;font-size:14px;color:#666}.demo-notes{margin-top:48px;padding:24px;background:#f8fafc;border-radius:8px;border:1px solid #e2e8f0}.demo-notes h3{color:#333;margin-bottom:16px}.demo-notes ul{list-style:none;padding:0;margin:0}.demo-notes ul li{color:#64748b;margin-bottom:12px;padding-left:24px;position:relative}.demo-notes ul li:before{content:\"\\2192\";position:absolute;left:0;color:#3b82f6}.demo-notes ul li:last-child{margin-bottom:0}.interface-description{margin-bottom:24px}.interface-description p{color:#64748b;margin-bottom:16px}.interface-description pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.interface-description pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155;line-height:1.6}.interface-usage{margin-bottom:24px}.interface-usage h5{color:#1e40af;margin-bottom:12px;font-size:16px}.interface-usage pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.interface-usage pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155;line-height:1.6}.interface-usage pre code .comment{color:#64748b}.interface-notes{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0}.interface-notes h5{color:#1e40af;margin-bottom:12px;font-size:16px}.interface-notes ul{list-style:none;padding:0;margin:0}.interface-notes ul li{color:#64748b;margin-bottom:8px;padding-left:20px;position:relative}.interface-notes ul li:before{content:\"\\2022\";position:absolute;left:0;color:#3b82f6}.interface-notes ul li:last-child{margin-bottom:0}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: LibsUiComponentsScrollOverlayDirective, selector: "[LibsUiComponentsScrollOverlayDirective]", inputs: ["debugMode", "ignoreInit", "classContainer", "options", "elementCheckScrollX", "elementCheckScrollY", "elementScroll"], outputs: ["outScroll", "outScrollX", "outScrollY", "outScrollTop", "outScrollBottom"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsScrollOverlayDemoComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-scroll-overlay-demo', standalone: true, imports: [CommonModule, LibsUiComponentsScrollOverlayDirective], template: "<div class=\"demo-container\">\n  <h2>Scroll Overlay Demo</h2>\n\n  <div class=\"demo-intro\">\n    <h3>Gi\u1EDBi thi\u1EC7u</h3>\n    <p>Demo n\u00E0y minh h\u1ECDa c\u00E1c t\u00EDnh n\u0103ng v\u00E0 c\u00E1ch s\u1EED d\u1EE5ng c\u1EE7a directive `scroll-overlay`. Demo bao g\u1ED3m 5 v\u00ED d\u1EE5 ch\u00EDnh:</p>\n    <ul>\n      <li><strong>Basic Usage</strong>: S\u1EED d\u1EE5ng c\u01A1 b\u1EA3n v\u1EDBi c\u1EA5u h\u00ECnh m\u1EB7c \u0111\u1ECBnh</li>\n      <li><strong>Custom Styling</strong>: Tu\u1EF3 ch\u1EC9nh m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc v\u00E0 padding c\u1EE7a thanh cu\u1ED9n</li>\n      <li><strong>Auto Hide</strong>: \u1EA8n/hi\u1EC7n thanh cu\u1ED9n khi hover</li>\n      <li><strong>Horizontal Scroll</strong>: Cu\u1ED9n ngang v\u1EDBi n\u1ED9i dung d\u00E0i</li>\n      <li><strong>Event Handling</strong>: X\u1EED l\u00FD c\u00E1c s\u1EF1 ki\u1EC7n scroll</li>\n    </ul>\n  </div>\n\n  <div class=\"demo-features\">\n    <h3>T\u00EDnh n\u0103ng Demo</h3>\n    <div class=\"features-grid\">\n      <div class=\"feature-item\">\n        <h4>Tu\u1EF3 bi\u1EBFn giao di\u1EC7n</h4>\n        <p>Thay \u0111\u1ED5i m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc, padding c\u1EE7a thanh cu\u1ED9n</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Hi\u1EC7u \u1EE9ng t\u01B0\u01A1ng t\u00E1c</h4>\n        <p>Hover effects, auto-hide khi kh\u00F4ng s\u1EED d\u1EE5ng</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>\u0110a h\u01B0\u1EDBng cu\u1ED9n</h4>\n        <p>H\u1ED7 tr\u1EE3 c\u1EA3 cu\u1ED9n d\u1ECDc v\u00E0 ngang</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Event handling</h4>\n        <p>Theo d\u00F5i c\u00E1c s\u1EF1 ki\u1EC7n scroll (top, bottom, scroll)</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>Responsive</h4>\n        <p>Ho\u1EA1t \u0111\u1ED9ng t\u1ED1t tr\u00EAn m\u1ECDi k\u00EDch th\u01B0\u1EDBc m\u00E0n h\u00ECnh</p>\n      </div>\n      <div class=\"feature-item\">\n        <h4>T\u00EDch h\u1EE3p d\u1EC5 d\u00E0ng</h4>\n        <p>C\u00F3 th\u1EC3 th\u00EAm v\u00E0o b\u1EA5t k\u1EF3 container n\u00E0o</p>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"demo-api\">\n    <h3>API Reference</h3>\n\n    <div class=\"api-section\">\n      <h4>Inputs</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Input</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>options</td>\n              <td>IScrollOverlayOptions</td>\n              <td>Tu\u1EF3 ch\u1ECDn c\u1EA5u h\u00ECnh thanh cu\u1ED9n</td>\n            </tr>\n            <tr>\n              <td>debugMode</td>\n              <td>boolean</td>\n              <td>B\u1EADt ch\u1EBF \u0111\u1ED9 debug</td>\n            </tr>\n            <tr>\n              <td>ignoreInit</td>\n              <td>boolean</td>\n              <td>B\u1ECF qua kh\u1EDFi t\u1EA1o directive</td>\n            </tr>\n            <tr>\n              <td>classContainer</td>\n              <td>string</td>\n              <td>Th\u00EAm class cho container b\u1ECDc ngo\u00E0i</td>\n            </tr>\n            <tr>\n              <td>notShowScrollBarX</td>\n              <td>boolean</td>\n              <td>Kh\u00F4ng hi\u1EC3n th\u1ECB thanh cu\u1ED9n ngang</td>\n            </tr>\n            <tr>\n              <td>notShowScrollBarY</td>\n              <td>boolean</td>\n              <td>Kh\u00F4ng hi\u1EC3n th\u1ECB thanh cu\u1ED9n d\u1ECDc</td>\n            </tr>\n            <tr>\n              <td>elementCheckScrollX</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED d\u00F9ng \u0111\u1EC3 ki\u1EC3m tra scroll X</td>\n            </tr>\n            <tr>\n              <td>elementCheckScrollY</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED d\u00F9ng \u0111\u1EC3 ki\u1EC3m tra scroll Y</td>\n            </tr>\n            <tr>\n              <td>elementScroll</td>\n              <td>HTMLElement</td>\n              <td>Ph\u1EA7n t\u1EED th\u1EF1c hi\u1EC7n scroll</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Outputs</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Output</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>outScroll</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll b\u1EA5t k\u1EF3</td>\n            </tr>\n            <tr>\n              <td>outScrollX</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll theo chi\u1EC1u ngang</td>\n            </tr>\n            <tr>\n              <td>outScrollY</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll theo chi\u1EC1u d\u1ECDc</td>\n            </tr>\n            <tr>\n              <td>outScrollTop</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll t\u1EDBi \u0111\u1EA7u (top)</td>\n            </tr>\n            <tr>\n              <td>outScrollBottom</td>\n              <td>Event</td>\n              <td>B\u1EAFn ra khi scroll t\u1EDBi cu\u1ED1i (bottom)</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Interface</h4>\n      <div class=\"interface-description\">\n        <p>Interface <code>IScrollOverlayOptions</code> \u0111\u1ECBnh ngh\u0129a c\u00E1c tu\u1EF3 ch\u1ECDn c\u1EA5u h\u00ECnh cho scroll-overlay directive:\n        </p>\n        <pre><code>export interface IScrollOverlayOptions {{ '{' }}\n  scrollbarWidth?: number;        // Chi\u1EC1u r\u1ED9ng thanh cu\u1ED9n (px)\n  scrollbarColor?: string;        // M\u00E0u n\u1EC1n track\n  scrollbarHoverColor?: string;   // M\u00E0u n\u1EC1n track khi hover\n  scrollThumbColor?: string;      // M\u00E0u thumb\n  scrollThumbHoverColor?: string; // M\u00E0u thumb khi hover\n  scrollbarPadding?: number;      // Padding c\u1EE7a scrollbar\n  scrollX?: 'hidden' | 'scroll';  // Ki\u1EC3u hi\u1EC3n th\u1ECB scroll X\n  scrollXOpacity0?: boolean;      // \u1EA8n track X khi kh\u00F4ng hover\n  scrollY?: 'hidden' | 'scroll';  // Ki\u1EC3u hi\u1EC3n th\u1ECB scroll Y\n  scrollYOpacity0?: boolean;      // \u1EA8n track Y khi kh\u00F4ng hover\n{{ '}' }}</code></pre>\n      </div>\n\n      <div class=\"interface-usage\">\n        <h5>V\u00ED d\u1EE5 s\u1EED d\u1EE5ng:</h5>\n        <pre><code>// C\u1EA5u h\u00ECnh c\u01A1 b\u1EA3n\nconst basicOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollbarWidth: 8,\n  scrollbarColor: '#f3f4f6',\n  scrollThumbColor: '#3b82f6'\n{{ '}' }};\n\n// C\u1EA5u h\u00ECnh n\u00E2ng cao v\u1EDBi hover effects\nconst advancedOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollbarWidth: 12,\n  scrollbarColor: '#f3f4f6',\n  scrollbarHoverColor: '#e5e7eb',\n  scrollThumbColor: '#3b82f6',\n  scrollThumbHoverColor: '#2563eb',\n  scrollbarPadding: 4,\n  scrollYOpacity0: true\n{{ '}' }};\n\n// C\u1EA5u h\u00ECnh cho scroll ngang\nconst horizontalOptions: IScrollOverlayOptions = {{ '{' }}\n  scrollX: 'scroll',\n  scrollY: 'hidden',\n  scrollbarWidth: 8,\n  scrollbarColor: '#f3f4f6',\n  scrollThumbColor: '#3b82f6'\n{{ '}' }};</code></pre>\n      </div>\n\n      <div class=\"interface-notes\">\n        <h5>Ghi ch\u00FA:</h5>\n        <ul>\n          <li>T\u1EA5t c\u1EA3 c\u00E1c thu\u1ED9c t\u00EDnh \u0111\u1EC1u l\u00E0 optional (c\u00F3 d\u1EA5u ?)</li>\n          <li>N\u1EBFu kh\u00F4ng cung c\u1EA5p gi\u00E1 tr\u1ECB, directive s\u1EBD s\u1EED d\u1EE5ng gi\u00E1 tr\u1ECB m\u1EB7c \u0111\u1ECBnh</li>\n          <li>C\u00F3 th\u1EC3 k\u1EBFt h\u1EE3p nhi\u1EC1u options \u0111\u1EC3 t\u1EA1o ra giao di\u1EC7n thanh cu\u1ED9n ph\u00F9 h\u1EE3p</li>\n          <li>M\u00E0u s\u1EAFc c\u00F3 th\u1EC3 s\u1EED d\u1EE5ng b\u1EA5t k\u1EF3 \u0111\u1ECBnh d\u1EA1ng CSS color n\u00E0o (hex, rgb, rgba, etc.)</li>\n          <li>scrollX v\u00E0 scrollY ch\u1EC9 nh\u1EADn m\u1ED9t trong hai gi\u00E1 tr\u1ECB: 'hidden' ho\u1EB7c 'scroll'</li>\n        </ul>\n      </div>\n    </div>\n\n    <div class=\"api-section\">\n      <h4>Options (IScrollOverlayOptions)</h4>\n      <div class=\"api-table\">\n        <table>\n          <thead>\n            <tr>\n              <th>Thu\u1ED9c t\u00EDnh</th>\n              <th>Type</th>\n              <th>M\u00F4 t\u1EA3</th>\n            </tr>\n          </thead>\n          <tbody>\n            <tr>\n              <td>scrollbarWidth</td>\n              <td>number</td>\n              <td>Chi\u1EC1u r\u1ED9ng thanh cu\u1ED9n (px)</td>\n            </tr>\n            <tr>\n              <td>scrollbarColor</td>\n              <td>string</td>\n              <td>M\u00E0u n\u1EC1n track</td>\n            </tr>\n            <tr>\n              <td>scrollbarHoverColor</td>\n              <td>string</td>\n              <td>M\u00E0u n\u1EC1n track khi hover</td>\n            </tr>\n            <tr>\n              <td>scrollThumbColor</td>\n              <td>string</td>\n              <td>M\u00E0u thumb</td>\n            </tr>\n            <tr>\n              <td>scrollThumbHoverColor</td>\n              <td>string</td>\n              <td>M\u00E0u thumb khi hover</td>\n            </tr>\n            <tr>\n              <td>scrollbarPadding</td>\n              <td>number</td>\n              <td>Padding c\u1EE7a scrollbar</td>\n            </tr>\n            <tr>\n              <td>scrollX</td>\n              <td>'hidden'|'scroll'</td>\n              <td>Ki\u1EC3u hi\u1EC3n th\u1ECB scroll X</td>\n            </tr>\n            <tr>\n              <td>scrollXOpacity0</td>\n              <td>boolean</td>\n              <td>\u1EA8n track X khi kh\u00F4ng hover</td>\n            </tr>\n            <tr>\n              <td>scrollY</td>\n              <td>'hidden'|'scroll'</td>\n              <td>Ki\u1EC3u hi\u1EC3n th\u1ECB scroll Y</td>\n            </tr>\n            <tr>\n              <td>scrollYOpacity0</td>\n              <td>boolean</td>\n              <td>\u1EA8n track Y khi kh\u00F4ng hover</td>\n            </tr>\n          </tbody>\n        </table>\n      </div>\n    </div>\n  </div>\n\n  <!-- Basic Demo -->\n  <div class=\"demo-section\">\n    <h3>1. Basic Usage</h3>\n    <div class=\"demo-description\">\n      <p>S\u1EED d\u1EE5ng c\u01A1 b\u1EA3n v\u1EDBi c\u1EA5u h\u00ECnh m\u1EB7c \u0111\u1ECBnh c\u1EE7a scroll-overlay directive.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     style=\"width: 300px; height: 200px;\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Custom Styling Demo -->\n  <div class=\"demo-section\">\n    <h3>2. Custom Styling</h3>\n    <div class=\"demo-description\">\n      <p>Tu\u1EF3 ch\u1EC9nh m\u00E0u s\u1EAFc, k\u00EDch th\u01B0\u1EDBc v\u00E0 padding c\u1EE7a thanh cu\u1ED9n.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollbarWidth: 12,\n       scrollbarColor: '#f3f4f6',\n       scrollThumbColor: '#3b82f6',\n       scrollbarPadding: 4\n     {{ '}' }}\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"customStyleOptions()\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Auto Hide Demo -->\n  <div class=\"demo-section\">\n    <h3>3. Auto Hide on Hover</h3>\n    <div class=\"demo-description\">\n      <p>\u1EA8n/hi\u1EC7n thanh cu\u1ED9n khi hover v\u00E0o container.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollYOpacity0: true,\n       scrollbarColor: 'transparent',\n       scrollThumbColor: '#9ca3af'\n     {{ '}' }}\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"autoHideOptions()\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Horizontal Scroll Demo -->\n  <div class=\"demo-section\">\n    <h3>4. Horizontal Scroll</h3>\n    <div class=\"demo-description\">\n      <p>Cu\u1ED9n ngang v\u1EDBi n\u1ED9i dung d\u00E0i.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     [options]=\"{{ '{' }}\"\n       scrollX: 'scroll',\n       scrollY: 'hidden'\n     {{ '}' }}\"&gt;\n  &lt;div style=\"white-space: nowrap;\"&gt;\n    N\u1ED9i dung ngang d\u00E0i...\n  &lt;/div&gt;\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        [options]=\"horizontalOptions()\"\n        style=\"width: 300px; height: 100px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px; white-space: nowrap;\">\n          {{ longHorizontalContent() }}\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <!-- Event Handling Demo -->\n  <div class=\"demo-section\">\n    <h3>5. Event Handling</h3>\n    <div class=\"demo-description\">\n      <p>X\u1EED l\u00FD c\u00E1c s\u1EF1 ki\u1EC7n scroll.</p>\n      <pre><code>&lt;div LibsUiComponentsScrollOverlayDirective\n     (outScroll)=\"onScroll($event)\"\n     (outScrollTop)=\"onScrollTop($event)\"\n     (outScrollBottom)=\"onScrollBottom($event)\"&gt;\n  N\u1ED9i dung d\u00E0i...\n&lt;/div&gt;</code></pre>\n    </div>\n    <div class=\"demo-box\">\n      <div LibsUiComponentsScrollOverlayDirective\n        (outScroll)=\"onScroll($event)\"\n        (outScrollTop)=\"onScrollTop($event)\"\n        (outScrollBottom)=\"onScrollBottom($event)\"\n        style=\"width: 300px; height: 200px; border: 1px solid #ddd;\">\n        <div style=\"padding: 16px;\">\n          {{ longContent() }}\n        </div>\n      </div>\n      <div class=\"event-log\">\n        <p>Last Event: {{ lastEvent() }}</p>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@charset \"UTF-8\";.demo-container{padding:24px;font-family:system-ui,-apple-system,sans-serif;max-width:1200px;margin:0 auto}.demo-intro{margin-bottom:32px}.demo-intro h3{color:#333;margin-bottom:16px}.demo-intro ul{list-style:none;padding:0}.demo-intro ul li{margin-bottom:8px;padding-left:20px;position:relative}.demo-intro ul li:before{content:\"\\2022\";position:absolute;left:0;color:#3b82f6}.demo-features{margin-bottom:32px}.demo-features h3{color:#333;margin-bottom:16px}.features-grid{display:grid;grid-template-columns:repeat(auto-fit,minmax(250px,1fr));gap:16px}.feature-item{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0}.feature-item h4{color:#1e40af;margin:0 0 8px}.feature-item p{margin:0;color:#64748b}.demo-api{margin-bottom:48px}.demo-api h3{color:#333;margin-bottom:24px}.api-section{margin-bottom:32px}.api-section h4{color:#1e40af;margin-bottom:16px}.api-table{overflow-x:auto}.api-table table{width:100%;border-collapse:collapse;background:#fff;border-radius:8px;border:1px solid #e2e8f0}.api-table table th,.api-table table td{padding:12px 16px;text-align:left;border-bottom:1px solid #e2e8f0}.api-table table th{background:#f8fafc;font-weight:600;color:#1e40af}.api-table table td{color:#64748b}.api-table table td:first-child{font-family:Fira Code,monospace;color:#334155}.api-table table td:nth-child(2){font-family:Fira Code,monospace;color:#3b82f6}.api-table table tr:last-child td{border-bottom:none}.demo-section{margin-bottom:48px}.demo-section h3{color:#333;margin-bottom:16px}.demo-description{margin-bottom:16px}.demo-description p{color:#64748b;margin-bottom:12px}.demo-description pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.demo-description pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155}.demo-box{display:flex;gap:16px;align-items:flex-start}.event-log{padding:16px;background:#f5f5f5;border-radius:4px;min-width:200px}.event-log p{margin:0;font-size:14px;color:#666}.demo-notes{margin-top:48px;padding:24px;background:#f8fafc;border-radius:8px;border:1px solid #e2e8f0}.demo-notes h3{color:#333;margin-bottom:16px}.demo-notes ul{list-style:none;padding:0;margin:0}.demo-notes ul li{color:#64748b;margin-bottom:12px;padding-left:24px;position:relative}.demo-notes ul li:before{content:\"\\2192\";position:absolute;left:0;color:#3b82f6}.demo-notes ul li:last-child{margin-bottom:0}.interface-description{margin-bottom:24px}.interface-description p{color:#64748b;margin-bottom:16px}.interface-description pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.interface-description pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155;line-height:1.6}.interface-usage{margin-bottom:24px}.interface-usage h5{color:#1e40af;margin-bottom:12px;font-size:16px}.interface-usage pre{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0;overflow-x:auto}.interface-usage pre code{font-family:Fira Code,monospace;font-size:14px;color:#334155;line-height:1.6}.interface-usage pre code .comment{color:#64748b}.interface-notes{background:#f8fafc;padding:16px;border-radius:8px;border:1px solid #e2e8f0}.interface-notes h5{color:#1e40af;margin-bottom:12px;font-size:16px}.interface-notes ul{list-style:none;padding:0;margin:0}.interface-notes ul li{color:#64748b;margin-bottom:8px;padding-left:20px;position:relative}.interface-notes ul li:before{content:\"\\2022\";position:absolute;left:0;color:#3b82f6}.interface-notes ul li:last-child{margin-bottom:0}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LibsUiComponentsScrollOverlayDemoComponent, LibsUiComponentsScrollOverlayDirective };
//# sourceMappingURL=libs-ui-components-scroll-overlay.mjs.map
